@@ -1,14 +1,14 @@
 #!/usr/bin/env python3
-from orger import StaticView
+from orger import Mirror
 from orger.inorganic import node, link
 from orger.common import dt_heading, error
 
-from my.hypothesis import get_pages
+import my.hypothesis as hypothesis
 
 
-class HypView(StaticView):
-    def get_items(self):
-        for page in get_pages():
+class HypView(Mirror):
+    def get_items(self) -> Mirror.Results:
+        for page in hypothesis.pages():
             # TODO would be nice to signal error upwards? Maybe just yield Exception, rener it in Orger and allow setting error status?
             if isinstance(page, Exception):
                 yield error(page)
