@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
-from orger import InteractiveView
+from orger import Queue
 from orger.inorganic import node, link
 from orger.common import todo
 
 from my.instapaper import pages, is_todo
 
 
-class IpTodos(InteractiveView):
+class IpTodos(Queue):
     def get_items(self):
         for page in pages():
             bm = page.bookmark
@@ -14,12 +14,14 @@ class IpTodos(InteractiveView):
                 if not is_todo(hl):
                     continue
                 yield hl.hid, todo(
+                    # todo dt_heading? not sure. Maybe this should be configurable
                     dt=hl.dt,
-                    heading=hl.text,
+                    heading=link(title="X", url=hl.instapaper_link) + ' ' + hl.text,
                     tags=['ip2org'],
-                    body=f'{hl.note}\nfrom {link(title="x", url=hl.instapaper_link)}   {link(title=bm.title, url=bm.url)}',
+                    body=f'{hl.note}\nfrom {link(title=bm.title, url=bm.url)}',
                 )
 
+
 if __name__ == '__main__':
     IpTodos.main()
 
