@@ -1,14 +1,14 @@
 #!/usr/bin/env python3
-from orger import StaticView
-from orger.inorganic import node, link
+from orger import Mirror
+from orger.inorganic import node, link, OrgNode
 from orger.common import dt_heading
 
 from my.books.kobo import get_books_with_highlights, Highlight
 
 
-class KoboView(StaticView):
-    def get_items(self):
-        def render_highlight(h: Highlight):
+class KoboView(Mirror):
+    def get_items(self) -> Mirror.Results:
+        def render_highlight(h: Highlight) -> OrgNode:
             # TODO FIXME could use bookmark page??
             heading = 'bookmark' if h.kind == 'bookmark' else (h.text or '')
             body = h.annotation # TODO check if empty
